@@ -11,10 +11,8 @@ use Moo::_Utils qw(
   _set_loaded
   _unimport_coderefs
 );
-use Sub::Defer ();
-use Sub::Quote qw(quote_sub sanitize_identifier);
-use Role::Tiny ();
 use Carp qw(croak);
+use Role::Tiny ();
 BEGIN { our @ISA = qw(Role::Tiny) }
 BEGIN {
   our @CARP_NOT = qw(
@@ -25,7 +23,7 @@ BEGIN {
   );
 }
 
-our $VERSION = '2.002005';
+our $VERSION = '2.003000';
 $VERSION = eval $VERSION;
 
 require Moo::sification;
@@ -171,6 +169,7 @@ sub _inhale_if_moose {
         my $spec = { %{ $is_mouse ? $attr : $attr->original_options } };
 
         if ($spec->{isa}) {
+          require Sub::Quote;
 
           my $get_constraint = do {
             my $pkg = $is_mouse
@@ -182,9 +181,9 @@ sub _inhale_if_moose {
 
           my $tc = $get_constraint->($spec->{isa});
           my $check = $tc->_compiled_type_constraint;
-          my $tc_var = '$_check_for_'.sanitize_identifier($tc->name);
+          my $tc_var = '$_check_for_'.Sub::Quote::sanitize_identifier($tc->name);
 
-          $spec->{isa} = quote_sub
+          $spec->{isa} = Sub::Quote::quote_sub(
             qq{
               &${tc_var} or Carp::croak "Type constraint failed for \$_[0]"
             },
@@ -192,7 +191,7 @@ sub _inhale_if_moose {
             {
               package => $role,
             },
-          ;
+          );
 
           if ($spec->{coerce}) {
 
@@ -261,7 +260,9 @@ sub _make_accessors {
 
 sub _undefer_subs {
   my ($self, $target, $role) = @_;
-  Sub::Defer::undefer_package($role);
+  if ($INC{'Sub/Defer.pm'}) {
+    Sub::Defer::undefer_package($role);
+  }
 }
 
 sub role_application_steps {
@@ -305,7 +306,7 @@ sub create_class_with_roles {
       and $m = Moo->_accessor_maker_for($superclass)
       and ref($m) ne 'Method::Generate::Accessor') {
     # old fashioned way time.
-    *{_getglob("${new_name}::ISA")} = [ $superclass ];
+    @{*{_getglob("${new_name}::ISA")}{ARRAY}} = ($superclass);
     $Moo::MAKERS{$new_name} = {is_class => 1};
     $me->apply_roles_to_package($new_name, @roles);
   }
@@ -318,6 +319,7 @@ sub create_class_with_roles {
   if ($INC{'Moo/HandleMoose.pm'} && !$Moo::sification::disabled) {
     Moo::HandleMoose::inject_fake_metaclass_for($new_name);
   }
+  $COMPOSED{class}{$new_name} = 1;
   _set_loaded($new_name, (caller)[1]);
   return $new_name;
 }
@@ -336,13 +338,11 @@ sub apply_roles_to_object {
         and keys %attrs
         and my $con_gen = Moo->_constructor_maker_for($class)
         and my $m = Moo->_accessor_maker_for($class)) {
-      require Sub::Quote;
 
       my $specs = $con_gen->all_attribute_specs;
 
       my %captures;
       my $code = join('',
-        "no warnings 'void';\n",
         ( map {
           my $name = $_;
           my $spec = $specs->{$name};
@@ -361,15 +361,21 @@ sub apply_roles_to_object {
           }
         } sort keys %attrs ),
       );
-      Sub::Quote::quote_sub(
-        "${class}::_apply_defaults",
-        $code,
-        \%captures,
-        {
-          package => $class,
-          no_install => 1,
-        }
-      );
+      if ($code) {
+        require Sub::Quote;
+        Sub::Quote::quote_sub(
+          "${class}::_apply_defaults",
+          "no warnings 'void';\n$code",
+          \%captures,
+          {
+            package => $class,
+            no_install => 1,
+          }
+        );
+      }
+      else {
+        0;
+      }
     }
     else {
       0;
